@@ -8,11 +8,13 @@ test_that("default pp_check method works", {
 
   expect_equal(
     pp_check(y, yrep[1:50, ], ppc_dens_overlay),
-    ppc_dens_overlay(y, yrep[1:50, ])
+    ppc_dens_overlay(y, yrep[1:50, ]),
+    check.environment = FALSE
   )
   expect_equal(
     pp_check(y, yrep, fun = "stat_grouped", group = g, stat = "median"),
-    ppc_stat_grouped(y, yrep, group = g, stat = "median")
+    ppc_stat_grouped(y, yrep, group = g, stat = "median"),
+    check.environment = FALSE
   )
 })
 
